# helpsk

Helper package for python.

- package source in `/src/helpsk`
- unit tests in `tests`


## Installing

`pip install helpsk`


## Unit Tests

The unit tests in this project are all found in the `tests` directory.

In the terminal, run the following in the root project directory:

> python -m unittest discover ./tests
